@@ -18,14 +18,12 @@ file is not what is expected.
 
 """
 
-__version__ = "0.4.1"
+__version__ = "0.8"
 
 import os.path
 import posixpath
 import traceback
-import types
 import zipfile
-from datetime import datetime
 
 from collada import animation
 from collada import asset
@@ -35,46 +33,51 @@ from collada import geometry
 from collada import light
 from collada import material
 from collada import scene
-from collada.common import E, tag
-from collada.common import DaeError, DaeObject, DaeIncompleteError, \
-    DaeBrokenRefError, DaeMalformedError, DaeUnsupportedError, \
-    DaeSaveValidationError
+from collada.common import E, tagger, tag
+from collada.common import DaeError, DaeIncompleteError, DaeBrokenRefError, \
+    DaeMalformedError, DaeSaveValidationError
 from collada.util import basestring, BytesIO
 from collada.util import IndexedList
+from collada.xmlutil import createElementTree
 from collada.xmlutil import etree as ElementTree
 from collada.xmlutil import writeXML
 
 try:
     from collada import schema
-except ImportError: # no lxml
+except ImportError:  # no lxml
     schema = None
 
 
 class Collada(object):
     """This is the main class used to create and load collada documents"""
 
-    geometries = property( lambda s: s._geometries, lambda s,v: s._setIndexedList('_geometries', v), doc="""
-    A list of :class:`collada.geometry.Geometry` objects. Can also be indexed by id""" )
-    controllers = property( lambda s: s._controllers, lambda s,v: s._setIndexedList('_controllers', v), doc="""
-    A list of :class:`collada.controller.Controller` objects. Can also be indexed by id""" )
-    animations = property( lambda s: s._animations, lambda s,v: s._setIndexedList('_animations', v), doc="""
-    A list of :class:`collada.animation.Animation` objects. Can also be indexed by id""" )
-    lights = property( lambda s: s._lights, lambda s,v: s._setIndexedList('_lights', v), doc="""
-    A list of :class:`collada.light.Light` objects. Can also be indexed by id""" )
-    cameras = property( lambda s: s._cameras, lambda s,v: s._setIndexedList('_cameras', v), doc="""
-    A list of :class:`collada.camera.Camera` objects. Can also be indexed by id""" )
-    images = property( lambda s: s._images, lambda s,v: s._setIndexedList('_images', v), doc="""
-    A list of :class:`collada.material.CImage` objects. Can also be indexed by id""" )
-    effects = property( lambda s: s._effects, lambda s,v: s._setIndexedList('_effects', v), doc="""
-    A list of :class:`collada.material.Effect` objects. Can also be indexed by id""" )
-    materials = property( lambda s: s._materials, lambda s,v: s._setIndexedList('_materials', v), doc="""
-    A list of :class:`collada.material.Effect` objects. Can also be indexed by id""" )
-    nodes = property( lambda s: s._nodes, lambda s,v: s._setIndexedList('_nodes', v), doc="""
-    A list of :class:`collada.scene.Node` objects. Can also be indexed by id""" )
-    scenes = property( lambda s: s._scenes, lambda s,v: s._setIndexedList('_scenes', v), doc="""
-    A list of :class:`collada.scene.Scene` objects. Can also be indexed by id""" )
+    geometries = property(lambda s: s._geometries, lambda s, v: s._setIndexedList('_geometries', v), doc="""
+    A list of :class:`collada.geometry.Geometry` objects. Can also be indexed by id""")
+    controllers = property(lambda s: s._controllers, lambda s, v: s._setIndexedList('_controllers', v), doc="""
+    A list of :class:`collada.controller.Controller` objects. Can also be indexed by id""")
+    animations = property(lambda s: s._animations, lambda s, v: s._setIndexedList('_animations', v), doc="""
+    A list of :class:`collada.animation.Animation` objects. Can also be indexed by id""")
+    lights = property(lambda s: s._lights, lambda s, v: s._setIndexedList('_lights', v), doc="""
+    A list of :class:`collada.light.Light` objects. Can also be indexed by id""")
+    cameras = property(lambda s: s._cameras, lambda s, v: s._setIndexedList('_cameras', v), doc="""
+    A list of :class:`collada.camera.Camera` objects. Can also be indexed by id""")
+    images = property(lambda s: s._images, lambda s, v: s._setIndexedList('_images', v), doc="""
+    A list of :class:`collada.material.CImage` objects. Can also be indexed by id""")
+    effects = property(lambda s: s._effects, lambda s, v: s._setIndexedList('_effects', v), doc="""
+    A list of :class:`collada.material.Effect` objects. Can also be indexed by id""")
+    materials = property(lambda s: s._materials, lambda s, v: s._setIndexedList('_materials', v), doc="""
+    A list of :class:`collada.material.Effect` objects. Can also be indexed by id""")
+    nodes = property(lambda s: s._nodes, lambda s, v: s._setIndexedList('_nodes', v), doc="""
+    A list of :class:`collada.scene.Node` objects. Can also be indexed by id""")
+    scenes = property(lambda s: s._scenes, lambda s, v: s._setIndexedList('_scenes', v), doc="""
+    A list of :class:`collada.scene.Scene` objects. Can also be indexed by id""")
 
-    def __init__(self, filename=None, ignore=None, aux_file_loader=None, zip_filename=None, validate_output=False):
+    def __init__(self,
+                 filename=None,
+                 ignore=None,
+                 aux_file_loader=None,
+                 zip_filename=None,
+                 validate_output=False):
         """Load collada data from filename or file like object.
 
         :param filename:
@@ -123,6 +126,9 @@ class Collada(object):
         self.scene = None
         """The default scene. This is either an instance of :class:`collada.scene.Scene` or `None`."""
 
+        # a function which will apply the namespace
+        self.tag = tag
+
         if validate_output and schema:
             self.validator = schema.ColladaValidator()
         else:
@@ -130,7 +136,7 @@ class Collada(object):
 
         self.maskedErrors = []
         if ignore is not None:
-            self.ignoreErrors( *ignore )
+            self.ignoreErrors(*ignore)
 
         if filename is None:
             self.filename = None
@@ -140,36 +146,37 @@ class Collada(object):
                 self.getFileData = self._wrappedFileLoader(aux_file_loader)
 
             self.xmlnode = ElementTree.ElementTree(
-                               E.COLLADA(
-                                   E.library_cameras(),
-                                   E.library_controllers(),
-                                   E.library_effects(),
-                                   E.library_geometries(),
-                                   E.library_images(),
-                                   E.library_lights(),
-                                   E.library_materials(),
-                                   E.library_nodes(),
-                                   E.library_visual_scenes(),
-                                   E.scene(),
-                               version='1.4.1'))
+                E.COLLADA(
+                    E.library_cameras(),
+                    E.library_controllers(),
+                    E.library_effects(),
+                    E.library_geometries(),
+                    E.library_images(),
+                    E.library_lights(),
+                    E.library_materials(),
+                    E.library_nodes(),
+                    E.library_visual_scenes(),
+                    E.scene(),
+                    version='1.4.1'))
             """ElementTree representation of the collada document"""
 
             self.assetInfo = asset.Asset()
             return
 
+        strdata = None
         if isinstance(filename, basestring):
-            fdata = open(filename, 'rb')
+            with open(filename, 'rb') as f:
+                strdata = f.read()
             self.filename = filename
             self.getFileData = self._getFileFromDisk
         else:
-            fdata = filename # assume it is a file like object
+            strdata = filename.read()  # assume it is a file like object
             self.filename = None
             self.getFileData = self._nullGetFile
-        strdata = fdata.read()
 
         try:
             self.zfile = zipfile.ZipFile(BytesIO(strdata), 'r')
-        except:
+        except BaseException:
             self.zfile = None
 
         if self.zfile:
@@ -196,13 +203,26 @@ class Collada(object):
         if aux_file_loader is not None:
             self.getFileData = self._wrappedFileLoader(aux_file_loader)
 
-        etree_parser = ElementTree.XMLParser()
         try:
-            self.xmlnode = ElementTree.ElementTree(element=None,
-                    file=BytesIO(data))
+            self.xmlnode = createElementTree(BytesIO(data))
         except ElementTree.ParseError as e:
             raise DaeMalformedError("XML Parsing Error: %s" % e)
 
+        # if we can't get the current namespace
+        # the tagger from above will use a hardcoded default
+        try:
+            # get the root node (whose tag is assumed to be COLLADA),
+            # and extract ns from its tag
+            xml_root = self.xmlnode.getroot()
+            namespace = xml_root.tag.split('}')[0].lstrip('{')
+
+            # create a tagging function using the extracted namespace
+            self.tag = tagger(namespace)
+        except BaseException:
+            # failed to extract a namespace, using default
+            traceback.print_exc()
+
+        # functions which will load various things into collada object
         self._loadAssetInfo()
         self._loadImages()
         self._loadEffects()
@@ -221,7 +241,10 @@ class Collada(object):
 
     def handleError(self, error):
         self.errors.append(error)
-        if not type(error) in self.maskedErrors:
+        # use `isinstance` to check this error which will
+        # correctly identify subclasses, i.e. if `DaeError`
+        # is passed as the ignore it will ignore everything
+        if not any(isinstance(error, mask) for mask in self.maskedErrors):
             raise
 
     def ignoreErrors(self, *args):
@@ -232,29 +255,30 @@ class Collada(object):
         mask so all exceptions abort the load just call c.ignoreErrors(None).
 
         """
-        if args == [ None ]:
+        if args == [None]:
             self.maskedErrors = []
         else:
-            for e in args: self.maskedErrors.append(e)
+            for e in args:
+                self.maskedErrors.append(e)
 
     def _getFileFromZip(self, fname):
         """Return the binary data of an auxiliary file from a zip archive as a string."""
         if not self.zfile:
-            raise DaeBrokenRefError('Trying to load an auxiliar file %s but we are not reading from a zip'%fname)
+            raise DaeBrokenRefError('Trying to load an auxiliary file %s but we are not reading from a zip' % fname)
         basepath = posixpath.dirname(self.filename)
         aux_path = posixpath.normpath(posixpath.join(basepath, fname))
         if aux_path not in self.zfile.namelist():
             raise DaeBrokenRefError('Auxiliar file %s not found in archive' % fname)
-        return self.zfile.read( aux_path )
+        return self.zfile.read(aux_path)
 
     def _getFileFromDisk(self, fname):
         """Return the binary data of an auxiliary file from the local disk relative to the file path loaded."""
         if self.zfile:
-            raise DaeBrokenRefError('Trying to load an auxiliar file %s from disk but we are reading from a zip file'%fname)
+            raise DaeBrokenRefError('Trying to load an auxiliary file %s from disk but we are reading from a zip file' % fname)
         basepath = os.path.dirname(self.filename)
         aux_path = os.path.normpath(os.path.join(basepath, fname))
         if not os.path.exists(aux_path):
-            raise DaeBrokenRefError('Auxiliar file %s not found on disk'%fname)
+            raise DaeBrokenRefError('Auxiliar file %s not found on disk' % fname)
         fdata = open(aux_path, 'rb')
         return fdata.read()
 
@@ -271,7 +295,7 @@ class Collada(object):
 
     def _loadAssetInfo(self):
         """Load information in <asset> tag"""
-        assetnode = self.xmlnode.find(tag('asset'))
+        assetnode = self.xmlnode.find(self.tag('asset'))
         if assetnode is not None:
             self.assetInfo = asset.Asset.load(self, {}, assetnode)
         else:
@@ -279,12 +303,12 @@ class Collada(object):
 
     def _loadGeometry(self):
         """Load geometry library."""
-        libnodes = self.xmlnode.findall(tag('library_geometries'))
+        libnodes = self.xmlnode.findall(self.tag('library_geometries'))
         if libnodes is not None:
             for libnode in libnodes:
                 if libnode is not None:
-                    for geomnode in libnode.findall(tag('geometry')):
-                        if geomnode.find(tag('mesh')) is None:
+                    for geomnode in libnode.findall(self.tag('geometry')):
+                        if geomnode.find(self.tag('mesh')) is None:
                             continue
                         try:
                             G = geometry.Geometry.load(self, {}, geomnode)
@@ -295,13 +319,13 @@ class Collada(object):
 
     def _loadControllers(self):
         """Load controller library."""
-        libnodes = self.xmlnode.findall(tag('library_controllers'))
+        libnodes = self.xmlnode.findall(self.tag('library_controllers'))
         if libnodes is not None:
             for libnode in libnodes:
                 if libnode is not None:
-                    for controlnode in libnode.findall(tag('controller')):
-                        if controlnode.find(tag('skin')) is None \
-                                and controlnode.find(tag('morph')) is None:
+                    for controlnode in libnode.findall(self.tag('controller')):
+                        if controlnode.find(self.tag('skin')) is None \
+                                and controlnode.find(self.tag('morph')) is None:
                             continue
                         try:
                             C = controller.Controller.load(self, {}, controlnode)
@@ -312,11 +336,11 @@ class Collada(object):
 
     def _loadAnimations(self):
         """Load animation library."""
-        libnodes = self.xmlnode.findall(tag('library_animations'))
+        libnodes = self.xmlnode.findall(self.tag('library_animations'))
         if libnodes is not None:
             for libnode in libnodes:
                 if libnode is not None:
-                    for animnode in libnode.findall(tag('animation')):
+                    for animnode in libnode.findall(self.tag('animation')):
                         try:
                             A = animation.Animation.load(self, {}, animnode)
                         except DaeError as ex:
@@ -326,11 +350,11 @@ class Collada(object):
 
     def _loadLights(self):
         """Load light library."""
-        libnodes = self.xmlnode.findall(tag('library_lights'))
+        libnodes = self.xmlnode.findall(self.tag('library_lights'))
         if libnodes is not None:
             for libnode in libnodes:
                 if libnode is not None:
-                    for lightnode in libnode.findall(tag('light')):
+                    for lightnode in libnode.findall(self.tag('light')):
                         try:
                             lig = light.Light.load(self, {}, lightnode)
                         except DaeError as ex:
@@ -340,11 +364,11 @@ class Collada(object):
 
     def _loadCameras(self):
         """Load camera library."""
-        libnodes = self.xmlnode.findall(tag('library_cameras'))
+        libnodes = self.xmlnode.findall(self.tag('library_cameras'))
         if libnodes is not None:
             for libnode in libnodes:
                 if libnode is not None:
-                    for cameranode in libnode.findall(tag('camera')):
+                    for cameranode in libnode.findall(self.tag('camera')):
                         try:
                             cam = camera.Camera.load(self, {}, cameranode)
                         except DaeError as ex:
@@ -354,11 +378,11 @@ class Collada(object):
 
     def _loadImages(self):
         """Load image library."""
-        libnodes = self.xmlnode.findall(tag('library_images'))
+        libnodes = self.xmlnode.findall(self.tag('library_images'))
         if libnodes is not None:
             for libnode in libnodes:
                 if libnode is not None:
-                    for imgnode in libnode.findall(tag('image')):
+                    for imgnode in libnode.findall(self.tag('image')):
                         try:
                             img = material.CImage.load(self, {}, imgnode)
                         except DaeError as ex:
@@ -368,11 +392,11 @@ class Collada(object):
 
     def _loadEffects(self):
         """Load effect library."""
-        libnodes = self.xmlnode.findall(tag('library_effects'))
+        libnodes = self.xmlnode.findall(self.tag('library_effects'))
         if libnodes is not None:
             for libnode in libnodes:
                 if libnode is not None:
-                    for effectnode in libnode.findall(tag('effect')):
+                    for effectnode in libnode.findall(self.tag('effect')):
                         try:
                             effect = material.Effect.load(self, {}, effectnode)
                         except DaeError as ex:
@@ -382,11 +406,11 @@ class Collada(object):
 
     def _loadMaterials(self):
         """Load material library."""
-        libnodes = self.xmlnode.findall(tag('library_materials'))
+        libnodes = self.xmlnode.findall(self.tag('library_materials'))
         if libnodes is not None:
             for libnode in libnodes:
                 if libnode is not None:
-                    for materialnode in libnode.findall(tag('material')):
+                    for materialnode in libnode.findall(self.tag('material')):
                         try:
                             mat = material.Material.load(self, {}, materialnode)
                         except DaeError as ex:
@@ -395,13 +419,13 @@ class Collada(object):
                             self.materials.append(mat)
 
     def _loadNodes(self):
-        libnodes = self.xmlnode.findall(tag('library_nodes'))
+        libnodes = self.xmlnode.findall(self.tag('library_nodes'))
         if libnodes is not None:
             for libnode in libnodes:
                 if libnode is not None:
                     tried_loading = []
                     succeeded = False
-                    for node in libnode.findall(tag('node')):
+                    for node in libnode.findall(self.tag('node')):
                         try:
                             N = scene.loadNode(self, node, {})
                         except scene.DaeInstanceNotLoadedError as ex:
@@ -433,11 +457,11 @@ class Collada(object):
 
     def _loadScenes(self):
         """Load scene library."""
-        libnodes = self.xmlnode.findall(tag('library_visual_scenes'))
+        libnodes = self.xmlnode.findall(self.tag('library_visual_scenes'))
         if libnodes is not None:
             for libnode in libnodes:
                 if libnode is not None:
-                    for scenenode in libnode.findall(tag('visual_scene')):
+                    for scenenode in libnode.findall(self.tag('visual_scene')):
                         try:
                             S = scene.Scene.load(self, scenenode)
                         except DaeError as ex:
@@ -447,12 +471,12 @@ class Collada(object):
 
     def _loadDefaultScene(self):
         """Loads the default scene from <scene> tag in the root node."""
-        node = self.xmlnode.find('%s/%s' % (tag('scene'), tag('instance_visual_scene')))
+        node = self.xmlnode.find('%s/%s' % (self.tag('scene'), self.tag('instance_visual_scene')))
         try:
-            if node != None:
+            if node is not None:
                 sceneid = node.get('url')
                 if not sceneid.startswith('#'):
-                    raise DaeMalformedError('Malformed default scene reference to %s: '%sceneid)
+                    raise DaeMalformedError('Malformed default scene reference to %s: ' % sceneid)
                 self.scene = self.scenes.get(sceneid[1:])
                 if not self.scene:
                     raise DaeBrokenRefError('Default scene %s not found' % sceneid)
@@ -472,23 +496,23 @@ class Collada(object):
                      (self.scenes, 'library_visual_scenes')]
 
         self.assetInfo.save()
-        assetnode = self.xmlnode.getroot().find(tag('asset'))
+        assetnode = self.xmlnode.getroot().find(self.tag('asset'))
         if assetnode is not None:
             self.xmlnode.getroot().remove(assetnode)
         self.xmlnode.getroot().insert(0, self.assetInfo.xmlnode)
 
         library_loc = 0
         for i, node in enumerate(self.xmlnode.getroot()):
-            if node.tag == tag('asset'):
-                library_loc = i+1
+            if node.tag == self.tag('asset'):
+                library_loc = i + 1
 
         for arr, name in libraries:
-            node = self.xmlnode.find( tag(name) )
+            node = self.xmlnode.find(self.tag(name))
             if node is None:
                 if len(arr) == 0:
                     continue
                 self.xmlnode.getroot().insert(library_loc, E(name))
-                node = self.xmlnode.find( tag(name) )
+                node = self.xmlnode.find(self.tag(name))
             elif node is not None and len(arr) == 0:
                 self.xmlnode.getroot().remove(node)
                 continue
@@ -502,7 +526,7 @@ class Collada(object):
                 if n not in xmlnodes:
                     node.remove(n)
 
-        scenenode = self.xmlnode.find(tag('scene'))
+        scenenode = self.xmlnode.find(self.tag('scene'))
         scenenode.clear()
         if self.scene is not None:
             sceneid = self.scene.id
@@ -512,8 +536,9 @@ class Collada(object):
 
         if self.validator is not None:
             if not self.validator.validate(self.xmlnode):
-                raise DaeSaveValidationError("Validation error when saving: " + 
-                        self.validator.COLLADA_SCHEMA_1_4_1_INSTANCE.error_log.last_error.message)
+                raise DaeSaveValidationError(
+                    "Validation error when saving: {}".format(
+                        self.validator.COLLADA_SCHEMA_1_4_1_INSTANCE.error_log.last_error.message))
 
     def write(self, fp):
         """Writes out the collada document to a file. Note that this also
@@ -534,4 +559,3 @@ class Collada(object):
 
     def __repr__(self):
         return str(self)
-
