@@ -12,7 +12,6 @@
 
 """Contains objects for representing a geometry."""
 
-import numpy
 
 from collada import source
 from collada import triangleset
@@ -21,16 +20,14 @@ from collada import polylist
 from collada import polygons
 from collada import primitive
 from collada.common import DaeObject, E, tag
-from collada.common import DaeIncompleteError, DaeBrokenRefError, \
-        DaeMalformedError, DaeUnsupportedError
-from collada.xmlutil import etree as ElementTree
+from collada.common import DaeIncompleteError, DaeUnsupportedError
 
 
 class Geometry(DaeObject):
     """A class containing the data coming from a COLLADA <geometry> tag"""
 
     def __init__(self, collada, id, name, sourcebyid, primitives=None,
-            xmlnode=None, double_sided=False):
+                 xmlnode=None, double_sided=False):
         """Create a geometry instance
 
           :param collada.Collada collada:
@@ -78,7 +75,7 @@ class Geometry(DaeObject):
         if primitives is not None:
             self.primitives = primitives
 
-        if xmlnode != None:
+        if xmlnode is not None:
             self.xmlnode = xmlnode
             """ElementTree representation of the geometry."""
         else:
@@ -87,16 +84,18 @@ class Geometry(DaeObject):
             for srcid, src in self.sourceById.items():
                 sourcenodes.append(src.xmlnode)
                 if verticesnode is None:
-                    #pick first source to be in the useless <vertices> tag
-                    verticesnode = E.vertices(E.input(semantic='POSITION', source="#%s"%srcid),
+                    # pick first source to be in the useless <vertices> tag
+                    verticesnode = E.vertices(E.input(semantic='POSITION', source="#%s" % srcid),
                                               id=srcid + '-vertices')
             meshnode = E.mesh(*sourcenodes)
             meshnode.append(verticesnode)
             self.xmlnode = E.geometry(meshnode)
-            if len(self.id) > 0: self.xmlnode.set("id", self.id)
-            if len(self.name) > 0: self.xmlnode.set("name", self.name)
+            if len(self.id) > 0:
+                self.xmlnode.set("id", self.id)
+            if len(self.name) > 0:
+                self.xmlnode.set("name", self.name)
 
-    def createLineSet(self, indices, inputlist, materialid):
+    def createLineSet(self, indices, inputlist, materialid=None):
         """Create a set of lines for use in this geometry instance.
 
         :param numpy.array indices:
@@ -113,7 +112,7 @@ class Geometry(DaeObject):
         inputdict = primitive.Primitive._getInputsFromList(self.collada, self.sourceById, inputlist.getList())
         return lineset.LineSet(inputdict, materialid, indices)
 
-    def createTriangleSet(self, indices, inputlist, materialid):
+    def createTriangleSet(self, indices, inputlist, materialid=None):
         """Create a set of triangles for use in this geometry instance.
 
         :param numpy.array indices:
@@ -130,7 +129,7 @@ class Geometry(DaeObject):
         inputdict = primitive.Primitive._getInputsFromList(self.collada, self.sourceById, inputlist.getList())
         return triangleset.TriangleSet(inputdict, materialid, indices)
 
-    def createPolylist(self, indices, vcounts, inputlist, materialid):
+    def createPolylist(self, indices, vcounts, inputlist, materialid=None):
         """Create a polylist for use with this geometry instance.
 
         :param numpy.array indices:
@@ -150,7 +149,7 @@ class Geometry(DaeObject):
         inputdict = primitive.Primitive._getInputsFromList(self.collada, self.sourceById, inputlist.getList())
         return polylist.Polylist(inputdict, materialid, indices, vcounts)
 
-    def createPolygons(self, indices, inputlist, materialid):
+    def createPolygons(self, indices, inputlist, materialid=None):
         """Create a polygons for use with this geometry instance.
 
         :param numpy.array indices:
@@ -168,58 +167,58 @@ class Geometry(DaeObject):
         return polygons.Polygons(inputdict, materialid, indices)
 
     @staticmethod
-    def load( collada, localscope, node ):
+    def load(collada, localscope, node):
         id = node.get("id") or ""
         name = node.get("name") or ""
-        meshnode = node.find(tag('mesh'))
-        if meshnode is None: raise DaeUnsupportedError('Unknown geometry node')
+        meshnode = node.find(collada.tag('mesh'))
+        if meshnode is None:
+            raise DaeUnsupportedError('Unknown geometry node')
         sourcebyid = {}
         sources = []
-        sourcenodes = node.findall('%s/%s'%(tag('mesh'), tag('source')))
+        sourcenodes = node.findall('%s/%s' % (collada.tag('mesh'), collada.tag('source')))
         for sourcenode in sourcenodes:
             ch = source.Source.load(collada, {}, sourcenode)
             sources.append(ch)
             sourcebyid[ch.id] = ch
 
-        verticesnode = meshnode.find(tag('vertices'))
-        if verticesnode is None:
-            vertexsource = None
-        else:
+        verticesnode = meshnode.find(collada.tag('vertices'))
+        if verticesnode is not None:
             inputnodes = {}
-            for inputnode in verticesnode.findall(tag('input')):
+            for inputnode in verticesnode.findall(collada.tag('input')):
                 semantic = inputnode.get('semantic')
                 inputsource = inputnode.get('source')
                 if not semantic or not inputsource or not inputsource.startswith('#'):
                     raise DaeIncompleteError('Bad input definition inside vertices')
                 inputnodes[semantic] = sourcebyid.get(inputsource[1:])
-            if (not verticesnode.get('id') or len(inputnodes)==0 or
-                not 'POSITION' in inputnodes):
+            if (not verticesnode.get('id') or len(inputnodes) == 0 or
+                    'POSITION' not in inputnodes):
                 raise DaeIncompleteError('Bad vertices definition in mesh')
             sourcebyid[verticesnode.get('id')] = inputnodes
-            vertexsource = verticesnode.get('id')
+            verticesnode.get('id')
 
-        double_sided_node = node.find('.//%s//%s' % (tag('extra'), tag('double_sided')))
+        double_sided_node = node.find('.//%s//%s' % (collada.tag('extra'), collada.tag('double_sided')))
         double_sided = False
         if double_sided_node is not None and double_sided_node.text is not None:
             try:
                 val = int(double_sided_node.text)
                 if val == 1:
                     double_sided = True
-            except ValueError: pass
+            except ValueError:
+                pass
 
         _primitives = []
         for subnode in meshnode:
-            if subnode.tag == tag('polylist'):
-                _primitives.append( polylist.Polylist.load( collada, sourcebyid, subnode ) )
-            elif subnode.tag in (tag('triangles'), tag('tristrips'), tag('trifans')):
-                _primitives.append( triangleset.TriangleSet.load( collada, sourcebyid, subnode ) )
-            elif subnode.tag == tag('lines'):
-                _primitives.append( lineset.LineSet.load( collada, sourcebyid, subnode ) )
-            elif subnode.tag == tag('polygons'):
-                _primitives.append( polygons.Polygons.load( collada, sourcebyid, subnode ) )
-            elif subnode.tag != tag('source') and subnode.tag != tag('vertices') and subnode.tag != tag('extra'):
+            if subnode.tag == collada.tag('polylist'):
+                _primitives.append(polylist.Polylist.load(collada, sourcebyid, subnode))
+            elif subnode.tag in (collada.tag('triangles'), collada.tag('tristrips'), collada.tag('trifans')):
+                _primitives.append(triangleset.TriangleSet.load(collada, sourcebyid, subnode))
+            elif subnode.tag == collada.tag('lines'):
+                _primitives.append(lineset.LineSet.load(collada, sourcebyid, subnode))
+            elif subnode.tag == collada.tag('polygons'):
+                _primitives.append(polygons.Polygons.load(collada, sourcebyid, subnode))
+            elif subnode.tag != collada.tag('source') and subnode.tag != collada.tag('vertices') and subnode.tag != collada.tag('extra'):
                 raise DaeUnsupportedError('Unknown geometry tag %s' % subnode.tag)
-        geom = Geometry(collada, id, name, sourcebyid, _primitives, xmlnode=node, double_sided=double_sided )
+        geom = Geometry(collada, id, name, sourcebyid, _primitives, xmlnode=node, double_sided=double_sided)
         return geom
 
     def save(self):
@@ -228,22 +227,22 @@ class Geometry(DaeObject):
         for src in self.sourceById.values():
             if isinstance(src, source.Source):
                 src.save()
-                if src.xmlnode not in meshnode.getchildren():
+                if src.xmlnode not in meshnode:
                     meshnode.insert(0, src.xmlnode)
 
         deletenodes = []
         for oldsrcnode in meshnode.findall(tag('source')):
             if oldsrcnode not in [src.xmlnode
-                    for src in self.sourceById.values()
-                    if isinstance(src, source.Source)]:
+                                  for src in self.sourceById.values()
+                                  if isinstance(src, source.Source)]:
                 deletenodes.append(oldsrcnode)
         for d in deletenodes:
             meshnode.remove(d)
 
-        #Look through primitives to find a vertex source
+        # Look through primitives to find a vertex source
         vnode = self.xmlnode.find(tag('mesh')).find(tag('vertices'))
 
-        #delete any inputs in vertices tag that no longer exist and find the vertex input
+        # delete any inputs in vertices tag that no longer exist and find the vertex input
         delete_inputs = []
         for input_node in vnode.findall(tag('input')):
             if input_node.get('semantic') == 'POSITION':
@@ -264,7 +263,7 @@ class Geometry(DaeObject):
         vert_src = vnode.get('id')
         vert_ref = input_vnode.get('source')[1:]
 
-        if not(vert_src in vert_sources or vert_ref in vert_sources) and len(vert_sources) > 0:
+        if not (vert_src in vert_sources or vert_ref in vert_sources) and len(vert_sources) > 0:
             if vert_ref in self.sourceById and vert_ref in vert_sources:
                 new_source = vert_ref
             else:
@@ -273,7 +272,7 @@ class Geometry(DaeObject):
             input_vnode.set('source', '#' + new_source)
             vnode.set('id', new_source + '-vertices')
 
-        #any source references in primitives that are pointing to the
+        # any source references in primitives that are pointing to the
         # same source that the vertices tag is pointing to to instead
         # point to the vertices id
         vert_src = vnode.get('id')
@@ -288,14 +287,14 @@ class Geometry(DaeObject):
         self.xmlnode.set('name', self.name)
 
         for prim in self.primitives:
-            if type(prim) is triangleset.TriangleSet and prim.xmlnode.tag != tag('triangles'):
+            if isinstance(prim, triangleset.TriangleSet) and prim.xmlnode.tag != tag('triangles'):
                 prim._recreateXmlNode()
-            if prim.xmlnode not in meshnode.getchildren():
+            if prim.xmlnode not in meshnode:
                 meshnode.append(prim.xmlnode)
 
         deletenodes = []
         primnodes = [prim.xmlnode for prim in self.primitives]
-        for child in meshnode.getchildren():
+        for child in meshnode:
             if child.tag != tag('vertices') and child.tag != tag('source') and child not in primnodes:
                 deletenodes.append(child)
         for d in deletenodes:
@@ -325,7 +324,7 @@ class Geometry(DaeObject):
         return str(self)
 
 
-class BoundGeometry( object ):
+class BoundGeometry(object):
     """A geometry bound to a transform matrix and material mapping.
         This gets created when a geometry is instantiated in a scene.
         Do not create this manually."""
@@ -351,7 +350,7 @@ class BoundGeometry( object ):
         the bound geometry. Each value returned will be of base type
         :class:`collada.primitive.BoundPrimitive`"""
         for p in self._primitives:
-            boundp = p.bind( self.matrix, self.materialnodebysymbol )
+            boundp = p.bind(self.matrix, self.materialnodebysymbol)
             yield boundp
 
     def __str__(self):
@@ -359,4 +358,3 @@ class BoundGeometry( object ):
 
     def __repr__(self):
         return str(self)
-
