@@ -1,14 +1,16 @@
 import sys
-import os, os.path
+import os
+import os.path
 import traceback
 import time
 import argparse
 
 try:
     import collada
-except:
+except BaseException:
     sys.exit("Could not find pycollada library.")
-        
+
+
 def main():
 
     parser = argparse.ArgumentParser(
@@ -24,18 +26,18 @@ def main():
                         help='Print a summary at the end of how many files had warnings and errors')
     parser.add_argument('--zip', '-z', default=False, action='store_true',
                         help='Include .zip files when searching for files to load')
-    
+
     args = parser.parse_args()
-    
+
     if not os.path.isdir(args.directory):
         sys.exit("Given path '%s' is not a directory." % args.directory)
-    
+
     directories = [args.directory]
     collada_files = []
     while len(directories) > 0:
         directory = directories.pop()
         for name in os.listdir(directory):
-            fullpath = os.path.join(directory,name)
+            fullpath = os.path.join(directory, name)
             (root, ext) = os.path.splitext(fullpath)
             if os.path.isfile(fullpath) and ext.lower() == ".dae":
                 collada_files.append(fullpath)
@@ -43,24 +45,24 @@ def main():
                 collada_files.append(fullpath)
             elif os.path.isdir(fullpath):
                 directories.append(fullpath)
-    
+
     collada_files.sort()
-    
+
     file_success_count = 0
     file_warning_count = 0
     file_error_count = 0
-    
+
     for c in collada_files:
         (root, leaf) = os.path.split(c)
         print("'%s'..." % leaf,)
         sys.stdout.flush()
-     
+
         start_time = time.time()
-     
+
         try:
-            col = collada.Collada(c, \
-                ignore=[collada.DaeUnsupportedError, collada.DaeBrokenRefError])
-            
+            col = collada.Collada(c,
+                                  ignore=[collada.DaeUnsupportedError, collada.DaeBrokenRefError])
+
             if len(col.errors) > 0:
                 print("WARNINGS:", len(col.errors))
                 file_warning_count += 1
@@ -74,12 +76,12 @@ def main():
                                 print("   %s" % str(err))
                                 break
                         if ct > 1:
-                            print("   %s: %d additional warnings of this type" % (e, ct-1))
+                            print("   %s: %d additional warnings of this type" % (e, ct - 1))
             else:
                 print("SUCCESS")
                 file_success_count += 1
-                
-            #do some sanity checks looping through result
+
+            # do some sanity checks looping through result
             if not col.scene is None:
                 for geom in col.scene.objects('geometry'):
                     for prim in geom.primitives():
@@ -89,17 +91,17 @@ def main():
         except (KeyboardInterrupt, SystemExit):
             print()
             sys.exit("Keyboard interrupt. Exiting.")
-        except:
+        except BaseException:
             print("ERROR")
             file_error_count += 1
             if args.show_errors:
                 print()
                 traceback.print_exc()
                 print()
-            
+
         end_time = time.time()
         if args.show_time:
-            print("   Loaded in %.3f seconds" % (end_time-start_time))
+            print("   Loaded in %.3f seconds" % (end_time - start_time))
 
     if args.show_summary:
         print()
@@ -109,6 +111,7 @@ def main():
         print("Files loaded successfully: %d" % file_success_count)
         print("Files with warnings: %d" % file_warning_count)
         print("Files with errors: %d" % file_error_count)
-            
+
+
 if __name__ == "__main__":
     main()
